==> hs-gstreamer-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/gstreamer-0.12.0/register.sh <==
#!/bin/sh
echo 'name: gstreamer
version: 0.12.0
id: gstreamer-0.12.0-80faad5b49ca49fb7edc578128bf5931

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: This package provides a wrapper around the GStreamer C library. GStreamer is a library
             for constructing graphs of media-handling components. The applications it supports
             range from simple Ogg/Vorbis playback, audio/video streaming to complex audio
             (mixing) and video (non-linear editing) processing.
category: Media
author: Peter Gavin, Axel Simon
exposed: True
exposed-modules: Media.Streaming.GStreamer.Core.Signals
                 Media.Streaming.GStreamer.Core.Hierarchy
                 Media.Streaming.GStreamer.Core.MiniHierarchy
                 Media.Streaming.GStreamer.Core.Types
                 Media.Streaming.GStreamer.Core.Constants
                 Media.Streaming.GStreamer.Core.Init
                 Media.Streaming.GStreamer.Core.Object
                 Media.Streaming.GStreamer.Core.HierarchyBase
                 Media.Streaming.GStreamer.Core.MiniObject
                 Media.Streaming.GStreamer.Core.MiniHierarchyBase
                 Media.Streaming.GStreamer.Core.Element
                 Media.Streaming.GStreamer.Core.Pad
                 Media.Streaming.GStreamer.Core.GhostPad
                 Media.Streaming.GStreamer.Core.Bin
                 Media.Streaming.GStreamer.Core.Format
                 Media.Streaming.GStreamer.Core.ElementFactory
                 Media.Streaming.GStreamer.Core.Caps
                 Media.Streaming.GStreamer.Core.Structure
                 Media.Streaming.GStreamer.Core.Message
                 Media.Streaming.GStreamer.Core.Buffer
                 Media.Streaming.GStreamer.Core.Event
                 Media.Streaming.GStreamer.Core.Query
                 Media.Streaming.GStreamer.Core.Bus
                 Media.Streaming.GStreamer.Core.Clock
                 Media.Streaming.GStreamer.Core.PadTemplate
                 Media.Streaming.GStreamer.Core.ImplementsInterface
                 Media.Streaming.GStreamer.Core.Index
                 Media.Streaming.GStreamer.Core.IndexFactory
                 Media.Streaming.GStreamer.Core.Iterator
                 Media.Streaming.GStreamer.Core.Parse
                 Media.Streaming.GStreamer.Core.Pipeline
                 Media.Streaming.GStreamer.Core.Plugin
                 Media.Streaming.GStreamer.Core.PluginFeature
                 Media.Streaming.GStreamer.Core.Registry
                 Media.Streaming.GStreamer.Core.Segment
                 Media.Streaming.GStreamer.Core.SystemClock
                 Media.Streaming.GStreamer.Core.TagList
                 Media.Streaming.GStreamer.Core
                 Media.Streaming.GStreamer.Base.Constants
                 Media.Streaming.GStreamer.Base.Types
                 Media.Streaming.GStreamer.Base.BaseSrc
                 Media.Streaming.GStreamer.Base.BaseSink
                 Media.Streaming.GStreamer.Base.BaseTransform
                 Media.Streaming.GStreamer.Base.PushSrc
                 Media.Streaming.GStreamer.Base.Adapter
                 Media.Streaming.GStreamer.Base.CollectPads
                 Media.Streaming.GStreamer.Base
                 Media.Streaming.GStreamer.Controller.Types
                 Media.Streaming.GStreamer.Controller.Controller
                 Media.Streaming.GStreamer.Net.Types
                 Media.Streaming.GStreamer.Net.NetClientClock
                 Media.Streaming.GStreamer.DataProtocol.Constants
                 Media.Streaming.GStreamer.DataProtocol.DataProtocol
                 Media.Streaming.GStreamer.Audio.Constants
                 Media.Streaming.GStreamer.Audio.Types
                 Media.Streaming.GStreamer.Audio.Audio
                 Media.Streaming.GStreamer.Audio.AudioClock
                 Media.Streaming.GStreamer
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/gstreamer-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/gstreamer-0.12.0
              /usr/local/lib
hs-libraries: HSgstreamer-0.12.0
extra-libraries: gstaudio-0.10 gstinterfaces-0.10 gstbase-0.10
                 gstcontroller-0.10 gstdataprotocol-0.10 gstnet-0.10 gstreamer-0.10
                 gobject-2.0 gmodule-2.0 xml2 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gstreamer-0.10
              /usr/local/include/glib-2.0 /usr/local/include/libxml2
includes: hsgstreamer.h
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/gstreamer-0.12.0/html/gstreamer.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/gstreamer-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gstreamer-0.12.1.tbz: lib/ghc-7.0.4/cabal/gstreamer-0.12.1/register.sh <==
#!/bin/sh
echo 'name: gstreamer
version: 0.12.1
id: gstreamer-0.12.1-0983c0a47cda13c4814facd219c08d93

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: This package provides a wrapper around the GStreamer C library. GStreamer is a library
             for constructing graphs of media-handling components. The applications it supports
             range from simple Ogg/Vorbis playback, audio/video streaming to complex audio
             (mixing) and video (non-linear editing) processing.
category: Media
author: Peter Gavin, Axel Simon
exposed: True
exposed-modules: Media.Streaming.GStreamer.Core.Signals
                 Media.Streaming.GStreamer.Core.Hierarchy
                 Media.Streaming.GStreamer.Core.MiniHierarchy
                 Media.Streaming.GStreamer.Core.Types
                 Media.Streaming.GStreamer.Core.Constants
                 Media.Streaming.GStreamer.Core.Init
                 Media.Streaming.GStreamer.Core.Object
                 Media.Streaming.GStreamer.Core.HierarchyBase
                 Media.Streaming.GStreamer.Core.MiniObject
                 Media.Streaming.GStreamer.Core.MiniHierarchyBase
                 Media.Streaming.GStreamer.Core.Element
                 Media.Streaming.GStreamer.Core.Pad
                 Media.Streaming.GStreamer.Core.GhostPad
                 Media.Streaming.GStreamer.Core.Bin
                 Media.Streaming.GStreamer.Core.Format
                 Media.Streaming.GStreamer.Core.ElementFactory
                 Media.Streaming.GStreamer.Core.Caps
                 Media.Streaming.GStreamer.Core.Structure
                 Media.Streaming.GStreamer.Core.Message
                 Media.Streaming.GStreamer.Core.Buffer
                 Media.Streaming.GStreamer.Core.Event
                 Media.Streaming.GStreamer.Core.Query
                 Media.Streaming.GStreamer.Core.Bus
                 Media.Streaming.GStreamer.Core.Clock
                 Media.Streaming.GStreamer.Core.PadTemplate
                 Media.Streaming.GStreamer.Core.ImplementsInterface
                 Media.Streaming.GStreamer.Core.Index
                 Media.Streaming.GStreamer.Core.IndexFactory
                 Media.Streaming.GStreamer.Core.Iterator
                 Media.Streaming.GStreamer.Core.Parse
                 Media.Streaming.GStreamer.Core.Pipeline
                 Media.Streaming.GStreamer.Core.Plugin
                 Media.Streaming.GStreamer.Core.PluginFeature
                 Media.Streaming.GStreamer.Core.Registry
                 Media.Streaming.GStreamer.Core.Segment
                 Media.Streaming.GStreamer.Core.SystemClock
                 Media.Streaming.GStreamer.Core.TagList
                 Media.Streaming.GStreamer.Core
                 Media.Streaming.GStreamer.Base.Constants
                 Media.Streaming.GStreamer.Base.Types
                 Media.Streaming.GStreamer.Base.BaseSrc
                 Media.Streaming.GStreamer.Base.BaseSink
                 Media.Streaming.GStreamer.Base.BaseTransform
                 Media.Streaming.GStreamer.Base.PushSrc
                 Media.Streaming.GStreamer.Base.Adapter
                 Media.Streaming.GStreamer.Base.CollectPads
                 Media.Streaming.GStreamer.Base
                 Media.Streaming.GStreamer.Controller.Types
                 Media.Streaming.GStreamer.Controller.Controller
                 Media.Streaming.GStreamer.Net.Types
                 Media.Streaming.GStreamer.Net.NetClientClock
                 Media.Streaming.GStreamer.DataProtocol.Constants
                 Media.Streaming.GStreamer.DataProtocol.DataProtocol
                 Media.Streaming.GStreamer.Audio.Constants
                 Media.Streaming.GStreamer.Audio.Types
                 Media.Streaming.GStreamer.Audio.Audio
                 Media.Streaming.GStreamer.Audio.AudioClock
                 Media.Streaming.GStreamer
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/gstreamer-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/gstreamer-0.12.1
              /usr/local/lib
hs-libraries: HSgstreamer-0.12.1
extra-libraries: gstaudio-0.10 gstinterfaces-0.10 gstbase-0.10
                 gstcontroller-0.10 gstdataprotocol-0.10 gstnet-0.10 gstreamer-0.10
                 gobject-2.0 gmodule-2.0 xml2 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gstreamer-0.10
              /usr/local/include/glib-2.0 /usr/local/include/libxml2
includes: hsgstreamer.h
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/gstreamer-0.12.1/html/gstreamer.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/gstreamer-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
